keyring

package
v0.0.0-...-0b344dd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 20, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EnsureGeminiAPIKey

func EnsureGeminiAPIKey() error

EnsureGeminiAPIKey checks if the GEMINI_API_KEY environment variable is set. If not, it checks the system keyring or local credentials file. If still not found, it prompts the user interactively and offers to save it for future sessions.

Types

This section is empty.

Jump to